%global sover 19
%global mpi_list mpich openmpi

Summary:        Libraries for the Unidata network Common Data Form
Name:           netcdf
Version:        4.9.0
Release:        2%{?dist}

License:        NetCDF
URL:            http://www.unidata.ucar.edu/software/netcdf/
Source0:        https://github.com/Unidata/netcdf-c/archive/v%{version}/%{name}-%{version}.tar.gz

Patch3000:      netcdf-plugin.patch
Patch3001:      netcdf-file-inferencing.patch

BuildRequires: zlib-devel openssh-clients libtirpc-devel
BuildRequires: libcurl-devel libxml2-devel libzstd-devel m4
BuildRequires: blosc-devel hdf5-static hdf5-devel gawk
BuildRequires: libtool make chrpath doxygen

%ifarch %{valgrind_arches}
BuildRequires:  valgrind
%endif
Requires:       hdf5 = %{_hdf5_version}



%description
etCDF (Network Common Data Form) is a set of software libraries and
machine-independent data formats that support the creation, access,
and sharing of array-oriented scientific data. It is also a community
standard for sharing scientific data. The Unidata Program Center supports
and maintains netCDF programming interfaces for C, C++, Java, and Fortran.
Programming interfaces are also available for Python, IDL, MATLAB, R,
Ruby, and Perl.

Data in netCDF format is:

 - Self-Describing. A netCDF file includes information about the data it contains.
 - Portable. A netCDF file can be accessed by computers with different ways of storing integers, characters, and floating-point numbers.
 - Scalable. Small subsets of large datasets in various formats may be accessed efficiently through netCDF interfaces, even from remote servers.
 - Appendable. Data may be appended to a properly structured netCDF file without copying the dataset or redefining its structure.
 - Sharable. One writer and multiple readers may simultaneously access the same netCDF file.
 - Archivable. Access to all earlier forms of netCDF data will be supported by current and future versions of the software.

%package devel
Summary:        Development files for netcdf
Requires:       %{name} = %{version}-%{release}
Requires:       pkgconfig
Requires:       hdf5-devel
Requires:       libcurl-devel

%description devel
This package contains the netCDF C header files, shared devel libs, and 
man pages.


%package static
Summary:        Static libs for netcdf
Requires:       %{name} = %{version}-%{release}

%description static
This package contains the netCDF C static libs.


%package mpich
Summary: NetCDF mpich libraries
Requires: hdf5-mpich = %{_hdf5_version}
BuildRequires: mpich-devel
BuildRequires: hdf5-mpich-devel >= 1.8.4
Provides: %{name}-mpich2 = %{version}-%{release}

%description mpich
NetCDF parallel mpich libraries


%package mpich-devel
Summary: NetCDF mpich development files
Requires: %{name}-mpich = %{version}-%{release}
Requires: pkgconfig
Requires: hdf5-mpich-devel
Requires: libcurl-devel
Provides: %{name}-mpich2-devel = %{version}-%{release}

%description mpich-devel
NetCDF parallel mpich development files


%package mpich-static
Summary: NetCDF mpich static libraries
Requires: %{name}-mpich-devel = %{version}-%{release}
Provides: %{name}-mpich2-static = %{version}-%{release}

%description mpich-static
NetCDF parallel mpich static libraries

%package openmpi
Summary: NetCDF openmpi libraries
Requires: hdf5-openmpi = %{_hdf5_version}
BuildRequires: openmpi-devel
BuildRequires: hdf5-openmpi-devel >= 1.8.4

%description openmpi
NetCDF parallel openmpi libraries


%package openmpi-devel
Summary: NetCDF openmpi development files
Requires: %{name}-openmpi = %{version}-%{release}
Requires: openmpi-devel
Requires: pkgconfig
Requires: hdf5-openmpi-devel
Requires: libcurl-devel

%description openmpi-devel
NetCDF parallel openmpi development files


%package openmpi-static
Summary: NetCDF openmpi static libraries
Requires: %{name}-openmpi-devel = %{version}-%{release}

%description openmpi-static
NetCDF parallel openmpi static libraries


%prep
%autosetup -p1 -n %{name}-c-%{version}
./bootstrap


%build
%global _configure ../configure
export LDFLAGS="%{__global_ldflags} -L%{_libdir}/hdf"
export CFLAGS="%{optflags} -fno-strict-aliasing"
%global configure_opts \\\
           --enable-shared \\\
           --enable-netcdf-4 \\\
           --enable-dap \\\
           CPPFLAGS="-I%{_includedir}/hdf -DH5_USE_110_API" \\\
           LIBS="-ltirpc" \\\
           --disable-hdf4 \\\
           --disable-dap-remote-tests \\\
%{nil}

mkdir build
pushd build
ln -s ../configure .
%configure %{configure_opts} \
  --with-plugin-dir=%{_libdir}/hdf5/plugin
sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|CC="\(.*g..\)"|CC="\1 -Wl,--as-needed"|' \
    -i libtool
%make_build
popd

for mpi in %{mpi_list}
do
  mkdir $mpi
  pushd $mpi
  module load mpi/$mpi-%{_arch}
  ln -s ../configure .
  %configure %{configure_opts} \
    CC=mpicc \
    --libdir=%{_libdir}/$mpi/lib \
    --bindir=%{_libdir}/$mpi/bin \
    --sbindir=%{_libdir}/$mpi/sbin \
    --includedir=%{_includedir}/$mpi-%{_arch} \
    --datarootdir=%{_libdir}/$mpi/share \
    --mandir=%{_libdir}/$mpi/share/man \
    --with-plugin-dir=%{_libdir}/$mpi/hdf5/plugin \
    --disable-parallel-tests
  sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
      -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
      -e 's|CC="\(.*g..\)"|CC="\1 -Wl,--as-needed"|' \
      -i libtool
  %make_build
  module purge
  popd
done


%install
%make_install -C build
chrpath --delete %{buildroot}/%{_bindir}/nc{copy,dump,gen,gen3}
/bin/rm -f %{buildroot}%{_infodir}/dir
for mpi in %{mpi_list}
do
  module load mpi/$mpi-%{_arch}
  make -C $mpi install DESTDIR=%{buildroot}
  chrpath --delete %{buildroot}/%{_libdir}/$mpi/bin/nc{copy,dump,gen,gen3}
  module purge
done
find %{buildroot}/%{_libdir} -name \*.la -delete


%check
make -C build check || ( cat build/*/test-suite.log && exit 1 )
export OMPI_MCA_rmaps_base_oversubscribe=1
for mpi in %{mpi_list}
do
  module load mpi/$mpi-%{_arch}
  # may fail because run as root
  make -C $mpi check ||:
  module purge
done



%files
%license COPYRIGHT
%doc README.md RELEASE_NOTES.md
%{_bindir}/nccopy
%{_bindir}/ncdump
%{_bindir}/ncgen
%{_bindir}/ncgen3
%{_bindir}/nc4print
%{_bindir}/ocprint
%{_libdir}/hdf5/plugin/lib__nch5deflate.so
%{_libdir}/hdf5/plugin/lib__nch5shuffle.so
%{_libdir}/hdf5/plugin/lib__nch5bzip2.so
%{_libdir}/hdf5/plugin/lib__nch5zstd.so
%{_libdir}/hdf5/plugin/lib__nch5szip.so
%{_libdir}/hdf5/plugin/lib__nczhdf5filters.so
%{_libdir}/hdf5/plugin/lib__nczstdfilters.so
%{_libdir}/hdf5/plugin/lib__nch5fletcher32.so
%{_libdir}/hdf5/plugin/lib__nch5blosc.so
%{_libdir}/*.so.%{sover}*
%{_mandir}/man1/*

%files devel
%doc examples
%{_bindir}/nc-config
%{_includedir}/netcdf.h
%{_includedir}/netcdf_aux.h
%{_includedir}/netcdf_dispatch.h
%{_includedir}/netcdf_filter.h
%{_includedir}/netcdf_filter_build.h
%{_includedir}/netcdf_filter_hdf5_build.h
%{_includedir}/netcdf_json.h
%{_includedir}/netcdf_meta.h
%{_includedir}/netcdf_mem.h
%{_libdir}/libnetcdf.settings
%{_libdir}/*.so
%{_libdir}/pkgconfig/netcdf.pc
%{_mandir}/man3/*

%files static
%{_libdir}/*.a

%files mpich
%license COPYRIGHT
%doc README.md RELEASE_NOTES.md
%{_libdir}/mpich/bin/nccopy
%{_libdir}/mpich/bin/ncdump
%{_libdir}/mpich/bin/ncgen
%{_libdir}/mpich/bin/ncgen3
%{_libdir}/mpich/bin/nc4print
%{_libdir}/mpich/bin/ocprint
%{_libdir}/mpich/hdf5/plugin/*
%{_libdir}/mpich/lib/*.so.%{sover}*
%doc %{_libdir}/mpich/share/man/man1/*.1*

%files mpich-devel
%{_libdir}/mpich/bin/nc-config
%{_includedir}/mpich-%{_arch}/netcdf.h
%{_includedir}/mpich-%{_arch}/netcdf_aux.h
%{_includedir}/mpich-%{_arch}/netcdf_dispatch.h
%{_includedir}/mpich-%{_arch}/netcdf_filter.h
%{_includedir}/mpich-%{_arch}/netcdf_filter_build.h
%{_includedir}/mpich-%{_arch}/netcdf_filter_hdf5_build.h
%{_includedir}/mpich-%{_arch}/netcdf_json.h
%{_includedir}/mpich-%{_arch}/netcdf_meta.h
%{_includedir}/mpich-%{_arch}/netcdf_mem.h
%{_includedir}/mpich-%{_arch}/netcdf_par.h
%{_libdir}/mpich/lib/libnetcdf.settings
%{_libdir}/mpich/lib/*.so
%{_libdir}/mpich/lib/pkgconfig/%{name}.pc
%doc %{_libdir}/mpich/share/man/man3/*.3*

%files mpich-static
%{_libdir}/mpich/lib/*.a

%files openmpi
%license COPYRIGHT
%doc README.md RELEASE_NOTES.md
%{_libdir}/openmpi/bin/nccopy
%{_libdir}/openmpi/bin/ncdump
%{_libdir}/openmpi/bin/ncgen
%{_libdir}/openmpi/bin/ncgen3
%{_libdir}/openmpi/bin/nc4print
%{_libdir}/openmpi/bin/ocprint
%{_libdir}/openmpi/hdf5/plugin/*
%{_libdir}/openmpi/lib/*.so.%{sover}*
%doc %{_libdir}/openmpi/share/man/man1/*.1*

%files openmpi-devel
%{_libdir}/openmpi/bin/nc-config
%{_includedir}/openmpi-%{_arch}/netcdf.h
%{_includedir}/openmpi-%{_arch}/netcdf_aux.h
%{_includedir}/openmpi-%{_arch}/netcdf_dispatch.h
%{_includedir}/openmpi-%{_arch}/netcdf_filter.h
%{_includedir}/openmpi-%{_arch}/netcdf_filter_build.h
%{_includedir}/openmpi-%{_arch}/netcdf_filter_hdf5_build.h
%{_includedir}/openmpi-%{_arch}/netcdf_json.h
%{_includedir}/openmpi-%{_arch}/netcdf_meta.h
%{_includedir}/openmpi-%{_arch}/netcdf_mem.h
%{_includedir}/openmpi-%{_arch}/netcdf_par.h
%{_libdir}/openmpi/lib/libnetcdf.settings
%{_libdir}/openmpi/lib/*.so
%{_libdir}/openmpi/lib/pkgconfig/%{name}.pc
%{_libdir}/openmpi/share/man/man3/*.3*

%files openmpi-static
%{_libdir}/openmpi/lib/*.a


%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.9.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Apr 21 2023 cunshunxia <cunshunxia@tencent.com> - 4.9.0-1
- initial build
